PCF2127 and PCF2129 are high accuracy real-time-clock (RTC) module. This library provides simple interface to accessing clock information.

Dependents:   PCF2127_Demo PCF2127_Hello

PCF2127 and PCF2129

PCF2127T PCF2127T is in SO16 package

The PCF2127 and the PCF2129 are a CMOS Real Time Clock (RTC) and calendar with an integrated Temperature Compensated Crystal (Xtal) Oscillator (TCXO) and a 32.768 kHz quartz crystal optimized for very high accuracy and very low power consumption.
Both of PCF2127 and PCF2129 have a selectable I2C-bus or SPI-bus, a backup battery switch-over circuit, a programmable watchdog function, a timestamp function, and many other features.
On addition to this, the PCF2127 has 512 bytes of general-purpose static RAM.

These 4 types of RTC modules are software compatible. So this library "PCF2127" can be used all of those.
This library only supports I2C to communicate with the PCF2127/PCF2129.

Type variations

Main feature difference

type+/-3ppm accuracy range512 bytes RAMpackage
PCF2127T-30℃ to +80℃yesSO16
PCF2127AT-30℃ to +60℃yesSO20
PCF2129T-30℃ to +80℃not availableSO16
PCF2129AT-15℃ to +60℃not availableSO20

Pin assign

/media/uploads/nxp_ip/pcf2127_pcf2129_pin_assign.png

PCF2127T
PCF2127T

Connection between MCU and PCF2127/PCF2129

These examples show how the RTC module can be connected via I2C bus.

http://developer.mbed.org/media/components/pinouts/both_types_connection3.png

References

Revision:
1:700e0285cfd8
Parent:
0:1377bcf1455e
Child:
2:db76c68f998f
--- a/PCF2127.h	Thu Dec 04 04:58:24 2014 +0000
+++ b/PCF2127.h	Tue Dec 09 07:21:13 2014 +0000
@@ -2,8 +2,8 @@
  *  PCF2127 library
  *
  *  @author     Akifumi (Tedd) OKANO, NXP Semiconductors
- *  @version    1.5
- *  @date       04-Dec-2014
+ *  @version    1.6
+ *  @date       09-Dec-2014
  *
  *  PCF2127 is a "real time clock (RTC)" module which is including a Xtal and TCXO
  *  http://www.nxp.com/products/interface_and_connectivity/real_time_clocks/rtcs_with_temp_compensation/series/PCF2127.html
@@ -54,17 +54,38 @@
         Aging_offset
     }
     RegisterName;
-
+    
+    /** Error code */
+    typedef enum {
+        NO_ERROR                = 0,
+        CLOCK_INTEGRITY_FAIL    = 1,
+        I2C_ACCESS_FAIL         = 2,
+        TIME_FUNC_ERROR         = ((time_t)-1)
+    }
+    ErrorNum;
+    
     /** Create a PCF2127 instance connected to specified I2C pins with specified address
      *
      *  @param I2C_sda I2C-bus SDA pin
      *  @param I2C_scl I2C-bus SCL pin
      *  @param vControl_1 (option) data for Control_1 register
      *  @param vControl_2 (option) data for Control_2 register
-     *  @param vControl_3 (option) data for Control_3 register
+     *  @param vControl_3 (option) data for Control_3 register (default setting of battery switch-over function as standard mode)
+     *  @param vCLKOUT_ctl (option) data for CLKOUT_ctl register (default setting 1Hz output on CLKOUT pin)
+     CLKOUT_ctl
      */
-    PCF2127( PinName sda, PinName sdl, char vControl_1 = 0x03, char vControl_2 = 0x00, char vControl_3 = 0x60 );
+    PCF2127( PinName sda, PinName sdl, char vControl_1 = Cntl1, char vControl_2 = Cntl2, char vControl_3 = Cntl1, char vCLKOUT_ctl = ClkOut );
 
+    /** Create a PCF2127 instance connected to specified I2C pins with specified address
+     *
+     *  @param i2c I2C object (instance)
+     *  @param vControl_1 (option) data for Control_1 register (default setting generates interrupts by second and minute)
+     *  @param vControl_2 (option) data for Control_2 register
+     *  @param vControl_3 (option) data for Control_3 register (default setting of battery switch-over function as standard mode)
+     *  @param vCLKOUT_ctl (option) data for CLKOUT_ctl register (default setting 1Hz output on CLKOUT pin)
+     */
+    PCF2127( I2C &i2c, char vControl_1 = Cntl1, char vControl_2 = Cntl2, char vControl_3 = Cntl1, char vCLKOUT_ctl = ClkOut );
+    
     /** Destractor
      */
     ~PCF2127();
@@ -79,12 +100,18 @@
      *
      *  @param dtp Pointer to struct tm
      */
-    void    set_time( struct tm *dtp );
+    int     set_time( struct tm *dtp );
+    
+    /** Set the time
+     *
+     *  @param tp pointer to time_t
+     */
+    int     set_time( time_t *tp );
 
     /** Set the time
      *  @param s String data: The time information should be given in format of "YYYY MM DD HH MM SS"
      */
-    void    set_time( char *s );
+    int     set_time( char *s );
 
     /** Get time of day
      *
@@ -99,22 +126,33 @@
      *  @param addr Register address
      *  @param Integer data. Converted to BCD before writing inot the register.
      */
-    void    set_alarm( char addr, char s );
+    int     set_alarm( char addr, char s );
 
     /** Clear interrupt flag
      *
      *  Clears interrupt flags by writing 0x00 into Control_2 register
      *
      */
-    void    clear_intr( void );
+    int     clear_intr( void );
 
 private:
-    void set_register( char addr, char data );
-    char read_register( char addr );
-    char i2bcd( char n );
-    char bcd2i( char bcd );
 
-    I2C     i2c;
+    typedef enum {
+        Cntl1   = 0x03,
+        Cntl2   = 0x00,
+        Cntl3   = 0x00,
+        ClkOut  = 0x46
+    }
+    DefaultRegParam;
+    
+    int     init( char vControl_1, char vControl_2, char vControl_3, char vCLKOUT_ctl );
+    int     set_register( char addr, char data );
+    int     read_register( char addr );
+    char    i2bcd( char n );
+    char    bcd2i( char bcd );
+
+    I2C     *i2c_p;
+    I2C     &i2c;
     char    device_address;
 }
 ;
@@ -54,17 +54,38 @@
      *  @param I2C_sda I2C-bus SDA pin
      *  @param I2C_scl I2C-bus SCL pin
-     *  @param vControl_1 (option) data for Control_1 register
+     *  @param vControl_1 (option) data for Control_1 register (default setting generates interrupts by second and minute)
      *  @param vControl_2 (option) data for Control_2 register